Spelling patch: gcc directory

Joseph S. Myers jsm28@cam.ac.uk
Sun Oct 28 04:42:00 GMT 2001


I've applied this spelling patch to the mainline.

Index: ChangeLog.0
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.0,v
retrieving revision 1.9
diff -u -r1.9 ChangeLog.0
--- ChangeLog.0	1999/04/13 22:45:42	1.9
+++ ChangeLog.0	2001/10/28 12:32:45
@@ -3651,7 +3651,7 @@
 	now that we don't automatically know what the labels might be.
 	Let scan_region() remove unreferenced EH BEGIN/END labels.
 	* integrate.c (get_label_from_map): Put inlined labels onto the
-	permanent obstack since we dont know which ones might be exception
+	permanent obstack since we don't know which ones might be exception
 	labels.
 	(save_for_inline_copying): Make new copies of all the handlers.
 	(expand_inline_function): Make new copies of all the handlers.
Index: ChangeLog.1
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.1,v
retrieving revision 1.4
diff -u -r1.4 ChangeLog.1
--- ChangeLog.1	2001/03/03 19:41:07	1.4
+++ ChangeLog.1	2001/10/28 12:32:50
@@ -448,7 +448,7 @@
 
 Mon May  3 14:45:23 1999  Jeffrey A Law  (law@cygnus.com)
 
-	* mn10200.md (btst insns): btst does not leave cc0 in a useable
+	* mn10200.md (btst insns): btst does not leave cc0 in a usable
 	state for redundant tst eliminatino.
 	* mn10300.md (btst insns): Likewise.
 
Index: ChangeLog.2
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.2,v
retrieving revision 1.4
diff -u -r1.4 ChangeLog.2
--- ChangeLog.2	2001/10/07 18:02:42	1.4
+++ ChangeLog.2	2001/10/28 12:32:55
@@ -10993,7 +10993,7 @@
 	a rethrow symbol instead of an integer exception region number.
 	* flow.c (Make_edges): Use new exception nesting routines to determine
 	which handlers are reachable from a CALL or asynchronous insn.
-	Dont add an edge for calls with a REG_EH_REGION of -1 to non-local
+	Don't add an edge for calls with a REG_EH_REGION of -1 to non-local
 	goto receivers.
 	(delete_eh_regions): Update rethrow labels, and don't delete
 	regions which are the target of a rethrow.
Index: ChangeLog.3
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.3,v
retrieving revision 1.4
diff -u -r1.4 ChangeLog.3
--- ChangeLog.3	2001/03/03 19:41:07	1.4
+++ ChangeLog.3	2001/10/28 12:33:00
@@ -366,7 +366,7 @@
 	offset, plus handle DW_CFA_def_cfa_expression.
 	(def_cfa_1): Use to be dwarf2out_def_cfa, only now it uses a
 	cfa_loc record.
-	(dwarf2out_def_cfa): Entry point maintained for compatability.
+	(dwarf2out_def_cfa): Entry point maintained for compatibility.
 	(dwarf_cfi_name): Add DW_CFA_def_cfa_expression.
 	(cfa_reg, cfa_offset): Replace with cfa_loc record 'cfa'.
 	(cfa_store_reg, cfa_store_offset): Replace with cfa_loc 'cfa_store'.
@@ -7928,7 +7928,7 @@
 
 Thu Apr  6 00:30:50 2000  J"orn Rennecke <amylaar@cygnus.co.uk>
 
-	* sh.h (FUNCTION_ARG_PARTIAL_NREGS): Accomodate an unsigned
+	* sh.h (FUNCTION_ARG_PARTIAL_NREGS): Accommodate an unsigned
 	GET_MODE_SIZE.
 
 Wed Apr  5 23:17:10 2000  J"orn Rennecke <amylaar@cygnus.co.uk>
@@ -13338,7 +13338,7 @@
 	(arm_valid_type_attribute_p): New function: Return true if the
 	attribute is a valid, arm specific, attribute.
 	(arm_comp_type_attribute): New function: Return true if the
-	two types have compatable, arm specific, attributes.
+	two types have compatible, arm specific, attributes.
 
 	* config/arm/arm.h (CUMULATIVE_ARGS): Redefine to be a
 	structure.
@@ -13774,7 +13774,7 @@
 
 Tue Feb  8 07:53:55 2000  Jan Hubicka  <jh@suse.cz>
 
-	* i386.md (addqi3_cc): Fix contraints.
+	* i386.md (addqi3_cc): Fix constraints.
 
 Tue Feb  8 01:39:45 2000  Hans-Peter Nilsson  <hp@bitrange.com>
 
@@ -14858,7 +14858,7 @@
 
 2000-01-24  Christopher Faylor <cgf@cygnus.com>
 
-	* config/i386/t-cygwin: Accomodate new winsup directory layout
+	* config/i386/t-cygwin: Accommodate new winsup directory layout
 	when searching for include files.
 
 2000-01-24  Richard Henderson  <rth@cygnus.com>
Index: ChangeLog.4
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.4,v
retrieving revision 1.4
diff -u -r1.4 ChangeLog.4
--- ChangeLog.4	2001/03/03 19:41:07	1.4
+++ ChangeLog.4	2001/10/28 12:33:04
@@ -4017,7 +4017,7 @@
 
 2000-11-12  Mark Mitchell  <mark@codesourcery.com>
 
-	* jump.c (delete_computation): Don't assume that just becuase an
+	* jump.c (delete_computation): Don't assume that just because an
 	instruction sets a register, that register is dead.
 
 2000-11-12  Neil Booth  <neilb@earthling.net>
@@ -6719,8 +6719,8 @@
 2000-10-07  Will Cohen  <wcohen@redhat.com>, Kazu Hirata  <kazu@hxi.com>
 
 	* config/h8300/h8300.md: Remove the memory alternative and correct
-	the insn lengths in the templates for sign extention and zero
-	extention.
+	the insn lengths in the templates for sign extension and zero
+	extension.
 
 2000-10-07  Richard Henderson  <rth@cygnus.com>
 
@@ -13466,7 +13466,7 @@
 2000-07-24  Nick Clifton  <nickc@cygnus.com>
 
 	* config/arm/arm.c (emit_multi_reg_push): Generate a
-	REG_FRAME_RELEATED_NOTE that is compatable with the code in
+	REG_FRAME_RELEATED_NOTE that is compatible with the code in
 	dwarf2out_debug_frame_expr.
 
 2000-07-24  Jason Merrill  <jason@redhat.com>
Index: ChangeLog.5
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.5,v
retrieving revision 1.3
diff -u -r1.3 ChangeLog.5
--- ChangeLog.5	2001/07/02 20:23:53	1.3
+++ ChangeLog.5	2001/10/28 12:33:07
@@ -6180,7 +6180,7 @@
 	(next_ls_expr): Next expression in the list.
 	(simple_mem): Check if expression qualifies for ld/st expression list.
 	(invalidate_any_buried_refs): Remove from expression list if its
-	used in some other way we dont understand.
+	used in some other way we don't understand.
 	(compute_ld_motion_mems): Find all potential enhanced load motion
 	expression.
 	(trim_ld_motion_mems): Remove any expressions which are invalid.
@@ -9315,7 +9315,7 @@
 	null terminated.  Use the new search_from member variable
 	of cpp_buffer.
 	(_cpp_compare_file_date): Similarly.
-	(search_from): New function, similiar to actual_directory.
+	(search_from): New function, similar to actual_directory.
 	(actual_directory): Delete.
 	(remap_filename): Update.  loc->name may not be null terminated.
 	(struct file_name_list): Rename search_path.  Update.
@@ -12210,7 +12210,7 @@
 	* config/i386/i386.c (asm_output_function_prefix): Remove.
 	(ix86_asm_file_end): New.
 	(load_pic_register): Generate pic_label_name into a
-	staticly allocated buffer.
+	statically allocated buffer.
 	* config/i386/i386-protos.h: Update.
 	* config/i386/i386.h (ASM_OUTPUT_FUNCTION_PREFIX): Remove.
 	(ASM_FILE_END): New.
@@ -13931,7 +13931,7 @@
 2001-01-05  Alexandre Oliva  <aoliva@redhat.com>
 
 	* config/sh/sh.md (prget, prset): New insn types.
-	(return delay slot): Dont' allow prset.
+	(return delay slot): Don't allow prset.
 	(call, sfunc delay slot): Don't allow prget.
 	(movsi_i, movsi_ie, movsi_i_lowpart): Create separate alternatives
 	for prset and prget.
Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog,v
retrieving revision 1.11676
diff -u -r1.11676 ChangeLog
--- ChangeLog	2001/10/28 02:34:16	1.11676
+++ ChangeLog	2001/10/28 12:33:11
@@ -1,3 +1,13 @@
+2001-10-28  Joseph S. Myers  <jsm28@cam.ac.uk>
+
+	* ChangeLog.0, ChangeLog.1, ChangeLog.2, ChangeLog.3, ChangeLog.4,
+	ChangeLog.5, ChangeLog, ChangeLog.lib, FSFChangeLog.10, ONEWS,
+	c-common.c, caller-save.c, cfg.c, cfgcleanup.c, cfgrtl.c,
+	collect2.c, df.h, diagnostic.h, final.c, gcse.c, gthr.h,
+	haifa-sched.c, jump.c, local-alloc.c, profile.c, protoize.c,
+	regmove.c, reload1.c, rtlanal.c, sched-vis.c, ssa.c, stmt.c,
+	system.h, toplev.c: Fix spelling errors.
+
 Sat Oct 27 17:32:04 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
 	* gcse.c (insert_insn_end_bb): Don't assume PAT is a SET.
@@ -4974,7 +4984,7 @@
 2001-08-30  Kazu Hirata  <kazu@hxi.com>
 
 	* config/h8300/h8300.md (zero_extendqihi2): Changes to
-	define_expand to accomodate target-specific attributes.
+	define_expand to accommodate target-specific attributes.
 	(anonymous zero_extendqihi2 patterns): New.
 
 Thu Aug 30 18:10:56 2001  J"orn Rennecke <amylaar@redhat.com>
@@ -5714,7 +5724,7 @@
 
 	* final.c (LABEL_ALIGN_AFTER_BARRIER): Default to no alignment.
 	(final_scan_insn): Consider jump tables data even if we have no
-	independant text section if !JUMP_TABLES_IN_TEXT_SECTION.  Use
+	independent text section if !JUMP_TABLES_IN_TEXT_SECTION.  Use
 	ADDR_VEC_ALIGN.
 	* config/ia64/ia64.h (JUMP_TABLES_IN_TEXT_SECTION): Remove.
 	(ASM_OUTPUT_CASE_END): Remove.
@@ -6174,7 +6184,7 @@
 
 2001-08-18  Graham Stott  <grahams@redhat.com>
 
-	* config/mips/mips.md (adddi3_internal_2+1): Remove contraints from
+	* config/mips/mips.md (adddi3_internal_2+1): Remove constraints from
 	define_split.
 	(adddi3_internal_2+2): Likewise.
 	(eh_set_lr_di+1): Likewise.
@@ -8485,9 +8495,9 @@
 2001-07-31 Hartmut Penner <hpenner@de.ibm.com>
 
 	* doc/install.texi: Add s390 and s390x as new targets.
-	* doc/invoke.texi: Add documantation of S/390 and zSeries
+	* doc/invoke.texi: Add documentation of S/390 and zSeries
 	target options.
-	* doc/md.texi: Add documantation of S/390 and zSeries constraints.
+	* doc/md.texi: Add documentation of S/390 and zSeries constraints.
 
 2001-07-30  Roman Zippel  <zippel@linux-m68k.org>
 
Index: ChangeLog.lib
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.lib,v
retrieving revision 1.5
diff -u -r1.5 ChangeLog.lib
--- ChangeLog.lib	2001/03/03 19:41:07	1.5
+++ ChangeLog.lib	2001/10/28 12:33:12
@@ -43,7 +43,7 @@
 Wed Sep 10 15:14:20 1997  Jeffrey A Law  (law@cygnus.com)
 
 	* config.sub: Use "amigaos" instread of "amigados".  Still
-	recognize "amigados" for backward compatability.
+	recognize "amigados" for backward compatibility.
 
 Tue Sep  9 18:23:57 1997  Doug Evans  <dje@cygnus.com>
 
Index: FSFChangeLog.10
===================================================================
RCS file: /cvs/gcc/gcc/gcc/FSFChangeLog.10,v
retrieving revision 1.3
diff -u -r1.3 FSFChangeLog.10
--- FSFChangeLog.10	1999/01/27 01:41:34	1.3
+++ FSFChangeLog.10	2001/10/28 12:33:16
@@ -807,7 +807,7 @@
 	(hppa_expand_prologue): If optimizing for space, emit an out of
 	line prologue.
 	(hppa_expand_epilogue): Similarly.
-	(override_options): Optimizing for space is not compatable with
+	(override_options): Optimizing for space is not compatible with
 	either profiling or PIC code generation.
 	* pa.md (outline_prologue_call): New pattern.
 	(outline_epilogue_call): Likewise.
@@ -7968,7 +7968,7 @@
 
 Tue May  9 15:52:05 1995  Michael Meissner  <meissner@cygnus.com>
 
-	* config.sub: Recognize powerpcle as the little endian varient of
+	* config.sub: Recognize powerpcle as the little endian variant of
 	the PowerPC.  Recgonize ppc as a PowerPC variant, and ppcle as a
 	powerpcle variant.  Convert pentium into i586, not i486.  Add p5
 	alias for i586.  Map new x86 variants p6, k5, nexgen into i586
Index: ONEWS
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ONEWS,v
retrieving revision 1.1
diff -u -r1.1 ONEWS
--- ONEWS	2000/12/04 23:03:07	1.1
+++ ONEWS	2001/10/28 12:33:17
@@ -57,7 +57,7 @@
 
 GCC now supports a "--help" option to print detailed help information.
 
-cpplib has been greatly improved.  It is probably useable for some sites now
+cpplib has been greatly improved.  It is probably usable for some sites now
 (major missing feature is trigraphs).
 
 Memory footprint for the compiler has been significantly reduced for certain
Index: c-common.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/c-common.c,v
retrieving revision 1.266
diff -u -r1.266 c-common.c
--- c-common.c	2001/10/23 18:51:01	1.266
+++ c-common.c	2001/10/28 12:33:18
@@ -465,7 +465,7 @@
    now. RID indicates how it should be formatted and IDENTIFIER_NODE
    ID is its name (unfortunately C and C++ hold the RID values of
    keywords in different places, so we can't derive RID from ID in
-   this language independant code.  */
+   this language independent code.  */
 
 tree
 fname_decl (rid, id)
Index: caller-save.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/caller-save.c,v
retrieving revision 1.45
diff -u -r1.45 caller-save.c
--- caller-save.c	2001/10/11 03:15:23	1.45
+++ caller-save.c	2001/10/28 12:33:18
@@ -399,7 +399,7 @@
 		 regs are live during the call.  */
 	      REG_SET_TO_HARD_REG_SET (hard_regs_to_save,
 				       &chain->live_throughout);
-	      /* Save hard registers always in the widest mode availble.  */
+	      /* Save hard registers always in the widest mode available.  */
 	      for (regno = 0; regno < FIRST_PSEUDO_REGISTER; regno++)
 		if (TEST_HARD_REG_BIT (hard_regs_to_save, regno))
 		  save_mode [regno] = regno_save_mode [regno][1];
Index: cfg.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cfg.c,v
retrieving revision 1.12
diff -u -r1.12 cfg.c
--- cfg.c	2001/10/26 07:49:34	1.12
+++ cfg.c	2001/10/28 12:33:18
@@ -569,7 +569,7 @@
     }
 }
 
-/* Simple routies to easilly allocate AUX fields of basic blocks.  */
+/* Simple routies to easily allocate AUX fields of basic blocks.  */
 static struct obstack block_aux_obstack;
 static void *first_block_aux_obj = 0;
 static struct obstack edge_aux_obstack;
Index: cfgcleanup.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cfgcleanup.c,v
retrieving revision 1.13
diff -u -r1.13 cfgcleanup.c
--- cfgcleanup.c	2001/10/27 10:17:44	1.13
+++ cfgcleanup.c	2001/10/28 12:33:19
@@ -1009,7 +1009,7 @@
   edge e, e2, nexte2, nexte, fallthru;
   bool changed;
 
-  /* Nothing to do if there is not at least two incomming edges.  */
+  /* Nothing to do if there is not at least two incoming edges.  */
   if (!bb->pred || !bb->pred->pred_next)
     return false;
 
Index: cfgrtl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cfgrtl.c,v
retrieving revision 1.5
diff -u -r1.5 cfgrtl.c
--- cfgrtl.c	2001/10/27 10:17:44	1.5
+++ cfgrtl.c	2001/10/28 12:33:19
@@ -1133,7 +1133,7 @@
 
   /* Create the basic block note.
 
-     Where we place the note can have a noticable impact on the generated
+     Where we place the note can have a noticeable impact on the generated
      code.  Consider this cfg:
 
 		        E
@@ -1504,7 +1504,7 @@
    - overlapping of basic blocks
    - edge list correctness
    - headers of basic blocks (the NOTE_INSN_BASIC_BLOCK note)
-   - tails of basic blocks (ensure that boundary is necesary)
+   - tails of basic blocks (ensure that boundary is necessary)
    - scans body of the basic block for JUMP_INSN, CODE_LABEL
      and NOTE_INSN_BASIC_BLOCK
    - check that all insns are in the basic blocks
Index: collect2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/collect2.c,v
retrieving revision 1.124
diff -u -r1.124 collect2.c
--- collect2.c	2001/10/21 21:31:58	1.124
+++ collect2.c	2001/10/28 12:33:20
@@ -863,7 +863,7 @@
   putenv (xstrdup ("COLLECT_NO_DEMANGLE="));
 
 #if defined (COLLECT2_HOST_INITIALIZATION)
-  /* Perform system dependent initialization, if neccessary.  */
+  /* Perform system dependent initialization, if necessary.  */
   COLLECT2_HOST_INITIALIZATION;
 #endif
 
Index: df.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/df.h,v
retrieving revision 1.4
diff -u -r1.4 df.h
--- df.h	2001/08/28 23:43:20	1.4
+++ df.h	2001/10/28 12:33:20
@@ -68,7 +68,7 @@
   struct df_link *defs;		/* Head of insn-def chain.  */
   struct df_link *uses;		/* Head of insn-use chain.  */
   /* ???? The following luid field should be considerd private so that
-     we can change it on the fly to accomodate new insns?  */
+     we can change it on the fly to accommodate new insns?  */
   int luid;			/* Logical UID.  */
 #if 0
   rtx insn;			/* Backpointer to the insn.  */
Index: diagnostic.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/diagnostic.h,v
retrieving revision 1.36
diff -u -r1.36 diagnostic.h
--- diagnostic.h	2001/10/11 12:43:40	1.36
+++ diagnostic.h	2001/10/28 12:33:20
@@ -221,7 +221,7 @@
    displayed.  */
 #define diagnostic_finalizer(DC) (DC)->end_diagnostic
 
-/* Extention hook for client.  */
+/* Extension hook for client.  */
 #define diagnostic_auxiliary_data(DC) (DC)->x_data
 
 /* Client supplied function used to decode formats.  Can operate on both
Index: final.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/final.c,v
retrieving revision 1.213
diff -u -r1.213 final.c
--- final.c	2001/10/21 21:31:59	1.213
+++ final.c	2001/10/28 12:33:21
@@ -991,7 +991,7 @@
 	    branch_frequency += EDGE_FREQUENCY (e);
 	}
 
-      /* There are two purposes to align block with no fallthru incomming edge:
+      /* There are two purposes to align block with no fallthru incoming edge:
 	 1) to avoid fetch stalls when branch destination is near cache boundary
 	 2) to improve cache effciency in case the previous block is not executed
 	    (so it does not need to be in the cache).
Index: gcse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gcse.c,v
retrieving revision 1.160
diff -u -r1.160 gcse.c
--- gcse.c	2001/10/28 02:34:18	1.160
+++ gcse.c	2001/10/28 12:33:22
@@ -5251,7 +5251,7 @@
 	      continue;
 	    }
 
-	  /* See if we've got a useable memory load.  We handle it first
+	  /* See if we've got a usable memory load.  We handle it first
 	     in case it uses its address register as a dest (which kills
 	     the nonnull property).  */
 	  if (GET_CODE (SET_SRC (set)) == MEM
@@ -6063,7 +6063,7 @@
 /* Find all the 'simple' MEMs which are used in LOADs and STORES. Simple
    being defined as MEM loads and stores to symbols, with no
    side effects and no registers in the expression. If there are any 
-   uses/defs which dont match this criteria, it is invalidated and
+   uses/defs which don't match this criteria, it is invalidated and
    trimmed out later.  */
 
 static void 
Index: gthr.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gthr.h,v
retrieving revision 1.10
diff -u -r1.10 gthr.h
--- gthr.h	2001/10/09 22:40:12	1.10
+++ gthr.h	2001/10/28 12:33:22
@@ -49,7 +49,7 @@
      		to initialize __gthread_mutex_t to get a fast
 		non-recursive mutex.
      __GTHREAD_MUTEX_INIT_FUNCTION
-     		some systems can't initalize a mutex without a
+     		some systems can't initialize a mutex without a
 		function call.  On such systems, define this to a
 		function which looks like this:
 		  void __GTHREAD_MUTEX_INIT_FUNCTION (__gthread_mutex_t *)
Index: haifa-sched.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/haifa-sched.c,v
retrieving revision 1.189
diff -u -r1.189 haifa-sched.c
--- haifa-sched.c	2001/10/11 03:15:44	1.189
+++ haifa-sched.c	2001/10/28 12:33:23
@@ -1958,7 +1958,7 @@
 	}
     }
 
-  /* Find units used in this fuction, for visualization.  */
+  /* Find units used in this function, for visualization.  */
   if (sched_verbose)
     init_target_units ();
 
Index: jump.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/jump.c,v
retrieving revision 1.198
diff -u -r1.198 jump.c
--- jump.c	2001/10/11 03:15:50	1.198
+++ jump.c	2001/10/28 12:33:23
@@ -742,7 +742,7 @@
 		    mode = GET_MODE (XEXP (comparison, 1));
 		  break;
 		}
-	      /* We can get past reg-reg moves.  This may be usefull for model
+	      /* We can get past reg-reg moves.  This may be useful for model
 	         of i387 comparisons that first move flag registers around.  */
 	      if (REG_P (src))
 		{
Index: local-alloc.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/local-alloc.c,v
retrieving revision 1.94
diff -u -r1.94 local-alloc.c
--- local-alloc.c	2001/10/26 11:16:09	1.94
+++ local-alloc.c	2001/10/28 12:33:24
@@ -1586,7 +1586,7 @@
 	     discourage the register allocator from creating false
 	     dependencies.
 
-	     The adjustment value is choosen to indicate that this qty
+	     The adjustment value is chosen to indicate that this qty
 	     conflicts with all the qtys in the instructions immediately
 	     before and after the lifetime of this qty.
 
Index: profile.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/profile.c,v
retrieving revision 1.74
diff -u -r1.74 profile.c
--- profile.c	2001/10/10 11:33:25	1.74
+++ profile.c	2001/10/28 12:33:24
@@ -697,7 +697,7 @@
 
   /* Create spanning tree from basic block graph, mark each edge that is
      on the spanning tree.  We insert as many abnormal and critical edges
-     as possible to minimize number of edge splits necesary.  */
+     as possible to minimize number of edge splits necessary.  */
 
   find_spanning_tree (el);
 
Index: protoize.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/protoize.c,v
retrieving revision 1.68
diff -u -r1.68 protoize.c
--- protoize.c	2001/10/21 21:32:00	1.68
+++ protoize.c	2001/10/28 12:33:25
@@ -655,7 +655,7 @@
       }
     if (nchars == 0)
       break;
-    /* Arithmetic on void pointers is a gcc extention.  */
+    /* Arithmetic on void pointers is a gcc extension.  */
     ptr = (char *) ptr + nchars;
     left -= nchars;
   }
@@ -685,7 +685,7 @@
 		pname, shortpath (NULL, out_fname), xstrerror (errno_val));
 	return;
       }
-    /* Arithmetic on void pointers is a gcc extention.  */
+    /* Arithmetic on void pointers is a gcc extension.  */
     ptr = (char *) ptr + written;
     len -= written;
   }
Index: regmove.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/regmove.c,v
retrieving revision 1.117
diff -u -r1.117 regmove.c
--- regmove.c	2001/10/11 07:07:26	1.117
+++ regmove.c	2001/10/28 12:33:25
@@ -2290,7 +2290,7 @@
       if (!reg_mentioned_p (stack_pointer_rtx, x))
 	return -1;
       /* We are not able to handle correctly all possible memrefs containing
-         stack pointer, so this check is neccesary.  */
+         stack pointer, so this check is necessary.  */
       if (stack_memref_p (x))
 	{
 	  d->memlist = record_one_stack_memref (d->insn, xp, d->memlist);
Index: reload1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/reload1.c,v
retrieving revision 1.306
diff -u -r1.306 reload1.c
--- reload1.c	2001/10/26 13:01:37	1.306
+++ reload1.c	2001/10/28 12:33:28
@@ -8580,7 +8580,7 @@
   int min_labelno, n_labels;
   HARD_REG_SET ever_live_at_start, *label_live;
 
-  /* If reg+reg can be used in offsetable memory adresses, the main chunk of
+  /* If reg+reg can be used in offsetable memory addresses, the main chunk of
      reload has already used it where appropriate, so there is no use in
      trying to generate it now.  */
   if (double_reg_address_ok && INDEX_REG_CLASS != NO_REGS)
Index: sched-vis.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/sched-vis.c,v
retrieving revision 1.14
diff -u -r1.14 sched-vis.c
--- sched-vis.c	2001/10/21 21:32:01	1.14
+++ sched-vis.c	2001/10/28 12:33:28
@@ -90,7 +90,7 @@
 #define MAX_VISUAL_NO_UNIT 20
 rtx vis_no_unit[MAX_VISUAL_NO_UNIT];
 
-/* Finds units that are in use in this fuction.  Required only
+/* Finds units that are in use in this function.  Required only
    for visualization.  */
 
 void
Index: ssa.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ssa.c,v
retrieving revision 1.39
diff -u -r1.39 ssa.c
--- ssa.c	2001/09/28 13:01:41	1.39
+++ ssa.c	2001/10/28 12:33:30
@@ -1366,7 +1366,7 @@
   if (n_nodes == 0)
     return;
 
-  /* Build the auxilliary graph R(B). 
+  /* Build the auxiliary graph R(B). 
 
      The nodes of the graph are the members of the register partition
      present in Phi(B).  There is an edge from FIND(T0)->FIND(T1) for
Index: stmt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/stmt.c,v
retrieving revision 1.224
diff -u -r1.224 stmt.c
--- stmt.c	2001/10/25 12:42:15	1.224
+++ stmt.c	2001/10/28 12:33:31
@@ -1520,7 +1520,7 @@
 #ifdef MD_ASM_CLOBBERS
   /* Sometimes we wish to automatically clobber registers across an asm.
      Case in point is when the i386 backend moved from cc0 to a hard reg --
-     maintaining source-level compatability means automatically clobbering
+     maintaining source-level compatibility means automatically clobbering
      the flags register.  */
   MD_ASM_CLOBBERS (clobbers);
 #endif
Index: system.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/system.h,v
retrieving revision 1.106
diff -u -r1.106 system.h
--- system.h	2001/10/21 19:44:07	1.106
+++ system.h	2001/10/28 12:33:31
@@ -510,7 +510,7 @@
 
 /* Traditional C cannot initialize union members of structs.  Provide
    a macro which expands appropriately to handle it.  This only works
-   if you intend to initalize the union member to zero since it relies
+   if you intend to initialize the union member to zero since it relies
    on default initialization to zero in the traditional C case.  */
 #ifdef __STDC__
 #define UNION_INIT_ZERO , {0}
Index: toplev.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/toplev.c,v
retrieving revision 1.526
diff -u -r1.526 toplev.c
--- toplev.c	2001/10/25 17:56:51	1.526
+++ toplev.c	2001/10/28 12:33:33
@@ -4007,7 +4007,7 @@
     }
 }
 
-/* Parse a -d... comand line switch.  */
+/* Parse a -d... command line switch.  */
 
 static void
 decode_d_option (arg)
@@ -4060,7 +4060,7 @@
       }
 }
 
-/* Parse a -f... comand line switch.  ARG is the value after the -f.
+/* Parse a -f... command line switch.  ARG is the value after the -f.
    It is safe to access 'ARG - 2' to generate the full switch name.
    Return the number of strings consumed.  */
 
@@ -4164,7 +4164,7 @@
   return 1;
 }
 
-/* Parse a -W... comand line switch.  ARG is the value after the -W.
+/* Parse a -W... command line switch.  ARG is the value after the -W.
    It is safe to access 'ARG - 2' to generate the full switch name.
    Return the number of strings consumed.  */
 
@@ -4215,7 +4215,7 @@
   return 1;
 }
 
-/* Parse a -g... comand line switch.  ARG is the value after the -g.
+/* Parse a -g... command line switch.  ARG is the value after the -g.
    It is safe to access 'ARG - 2' to generate the full switch name.
    Return the number of strings consumed.  */
 

Index: rtlanal.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/rtlanal.c,v
retrieving revision 1.113
diff -u -r1.113 rtlanal.c
--- rtlanal.c	2001/10/19 19:42:46	1.113
+++ rtlanal.c	2001/10/28 12:33:28
@@ -923,7 +923,7 @@
 	      /* We can consider insns having multiple sets, where all
 		 but one are dead as single set insns.  In common case
 		 only single set is present in the pattern so we want
-		 to avoid checking for REG_UNUSED notes unless neccesary.
+		 to avoid checking for REG_UNUSED notes unless necessary.
 
 		 When we reach set first time, we just expect this is
 		 the single set we are looking for and only when more
@@ -2595,7 +2595,7 @@
   return 0;
 }
 
 /* Return 1 iff it is neccesary to swap operands of commutative operation
    in order to canonicalize expression.  */
 
 int
@@ -2595,7 +2595,7 @@
 }
 
-/* Return 1 iff it is neccesary to swap operands of commutative operation
+/* Return 1 iff it is necessary to swap operands of commutative operation
    in order to canonicalize expression.  */
 
-- 
Joseph S. Myers
jsm28@cam.ac.uk



More information about the Gcc-patches mailing list